Sets
====

.. automodule:: diofant.sets.sets

.. autoclass:: Set
   :members:

.. autofunction:: imageset

Elementary Sets
^^^^^^^^^^^^^^^

.. autoclass:: Interval
   :members:

.. autoclass:: FiniteSet
   :members:

Compound Sets
^^^^^^^^^^^^^

.. autoclass:: Union
   :members:

.. autoclass:: Intersection
   :members:

.. autoclass:: ProductSet
   :members:

.. autoclass:: Complement
   :members:

Singleton Sets
^^^^^^^^^^^^^^

.. autoclass:: EmptySet
   :members:

.. autoclass:: UniversalSet
   :members:

Special Sets
^^^^^^^^^^^^

.. automodule:: diofant.sets.fancysets

.. autoclass:: Naturals
   :members:

.. autoclass:: Naturals0
   :members:

.. autoclass:: Integers
   :members:

.. autoclass:: Rationals
   :members:

.. autoclass:: ImageSet
   :members:

.. autoclass:: Range
   :members:
